@@ -135,6 +135,14 @@ EXTERN const char *		named_g_defaultpidfile 	INIT(NAMED_LOCALSTATEDIR
 							     "/run/named.pid");
 #endif
 
+#ifdef HAVE_DNSTAP
+EXTERN const char *		named_g_defaultdnstap
+					INIT(NAMED_LOCALSTATEDIR "/run/named/"
+							      "dnstap.sock");
+#else
+EXTERN const char *		named_g_defaultdnstap	INIT(NULL);
+#endif /* HAVE_DNSTAP */
+
 EXTERN const char *		named_g_username	INIT(NULL);
 
 EXTERN const char *		named_g_engine		INIT(NULL);
@@ -146,7 +154,7 @@ EXTERN bool		named_g_keepstderr	INIT(false);
 
 EXTERN unsigned int		named_g_tat_interval	INIT(24*3600);
 
-#if defined(HAVE_GEOIP) || defined(HAVE_GEOIP2)
+#if defined(HAVE_GEOIP2)
 EXTERN dns_geoip_databases_t	*named_g_geoip		INIT(NULL);
 #endif
 
