@@ -166,7 +166,7 @@ main(int argc, char **argv) {
 	dns_result_register();
 
 	mctx = NULL;
-	RUNCHECK(isc_mem_create(0, 0, &mctx));
+	isc_mem_create(&mctx);
 
 	log = NULL;
 	logconfig = NULL;
