@@ -25,23 +25,18 @@
 
 #pragma once
 
-#include <config.h>
-
 #include <inttypes.h>
 #include <stdbool.h>
 
 #include <isc/lang.h>
 #include <isc/buffer.h>
 #include <isc/magic.h>
+#include <isc/md.h>
 #include <isc/region.h>
 #include <isc/types.h>
-#include <isc/md5.h>
 #include <isc/refcount.h>
-#include <isc/sha1.h>
-#include <isc/sha2.h>
 #include <isc/stdtime.h>
-#include <isc/hmacmd5.h>
-#include <isc/hmacsha.h>
+#include <isc/hmac.h>
 
 #if USE_PKCS11
 #include <pk11/pk11.h>
@@ -53,7 +48,6 @@
 #include <dst/dst.h>
 
 #include <openssl/dh.h>
-#include <openssl/dsa.h>
 #include <openssl/err.h>
 #include <openssl/evp.h>
 #include <openssl/objects.h>
@@ -67,20 +61,13 @@ ISC_LANG_BEGINDECLS
 #define VALID_KEY(x) ISC_MAGIC_VALID(x, KEY_MAGIC)
 #define VALID_CTX(x) ISC_MAGIC_VALID(x, CTX_MAGIC)
 
-LIBDNS_EXTERNAL_DATA extern isc_mem_t *dst__memory_pool;
-
 /***
  *** Types
  ***/
 
 typedef struct dst_func dst_func_t;
 
-typedef struct dst_hmacmd5_key	  dst_hmacmd5_key_t;
-typedef struct dst_hmacsha1_key   dst_hmacsha1_key_t;
-typedef struct dst_hmacsha224_key dst_hmacsha224_key_t;
-typedef struct dst_hmacsha256_key dst_hmacsha256_key_t;
-typedef struct dst_hmacsha384_key dst_hmacsha384_key_t;
-typedef struct dst_hmacsha512_key dst_hmacsha512_key_t;
+typedef struct dst_hmac_key	  dst_hmac_key_t;
 
 /*%
  * Indicate whether a DST context will be used for signing
@@ -109,7 +96,6 @@ struct dst_key {
 	union {
 		void *generic;
 		gss_ctx_id_t gssctx;
-		DSA *dsa;
 		DH *dh;
 #if USE_OPENSSL
 		EVP_PKEY *pkey;
@@ -117,13 +103,7 @@ struct dst_key {
 #if USE_PKCS11
 		pk11_object_t *pkey;
 #endif
-		dst_hmacmd5_key_t *hmacmd5;
-		dst_hmacsha1_key_t *hmacsha1;
-		dst_hmacsha224_key_t *hmacsha224;
-		dst_hmacsha256_key_t *hmacsha256;
-		dst_hmacsha384_key_t *hmacsha384;
-		dst_hmacsha512_key_t *hmacsha512;
-
+		dst_hmac_key_t *hmac_key;
 	} keydata;			/*%< pointer to key in crypto pkg fmt */
 
 	isc_stdtime_t	times[DST_MAX_TIMES + 1];    /*%< timing metadata */
@@ -150,16 +130,7 @@ struct dst_context {
 	union {
 		void *generic;
 		dst_gssapi_signverifyctx_t *gssctx;
-		isc_md5_t *md5ctx;
-		isc_sha1_t *sha1ctx;
-		isc_sha256_t *sha256ctx;
-		isc_sha512_t *sha512ctx;
-		isc_hmacmd5_t *hmacmd5ctx;
-		isc_hmacsha1_t *hmacsha1ctx;
-		isc_hmacsha224_t *hmacsha224ctx;
-		isc_hmacsha256_t *hmacsha256ctx;
-		isc_hmacsha384_t *hmacsha384ctx;
-		isc_hmacsha512_t *hmacsha512ctx;
+		isc_hmac_t *hmac_ctx;
 		EVP_MD_CTX *evp_md_ctx;
 #if USE_PKCS11
 		pk11_context_t *pk11_ctx;
@@ -216,7 +187,7 @@ struct dst_func {
 /*%
  * Initializers
  */
-isc_result_t dst__openssl_init(const char *engine);
+isc_result_t dst__openssl_init(isc_mem_t *, const char *engine);
 #define dst__pkcs11_init pk11_initialize
 
 isc_result_t dst__hmacmd5_init(struct dst_func **funcp);
@@ -229,7 +200,6 @@ isc_result_t dst__openssldh_init(struct dst_func **funcp);
 #if USE_OPENSSL
 isc_result_t dst__opensslrsa_init(struct dst_func **funcp,
 				  unsigned char algorithm);
-isc_result_t dst__openssldsa_init(struct dst_func **funcp);
 isc_result_t dst__opensslecdsa_init(struct dst_func **funcp);
 #if HAVE_OPENSSL_ED25519 || HAVE_OPENSSL_ED448
 isc_result_t dst__openssleddsa_init(struct dst_func **funcp);
