@@ -243,6 +243,7 @@ progress_cb(int p, int n, BN_GENCB *cb) {
 
 	UNUSED(n);
 
+	/* cppcheck-suppress unreadVariable */
 	u.dptr = BN_GENCB_get_arg(cb);
 	if (u.fptr != NULL)
 		u.fptr(p);
@@ -303,8 +304,9 @@ openssldh_generate(dst_key_t *key, int generator, void (*callback)(int)) {
 		if (callback == NULL) {
 			BN_GENCB_set_old(cb, NULL, NULL);
 		} else {
+			/* cppcheck-suppress unreadVariable */
 			u.fptr = callback;
-			BN_GENCB_set(cb, &progress_cb, u.dptr);
+			BN_GENCB_set(cb, progress_cb, u.dptr);
 		}
 
 		if (!DH_generate_parameters_ex(dh, key->key_size, generator,
