@@ -142,7 +142,7 @@ dns_test_begin(FILE *logfile, bool start_managers) {
 	}
 
 	INSIST(dt_mctx == NULL);
-	CHECK(isc_mem_create(0, 0, &dt_mctx));
+	isc_mem_create(&dt_mctx);
 
 	/* Don't check the memory leaks as they hide the assertions */
 	isc_mem_setdestroycheck(dt_mctx, false);
