@@ -14,6 +14,8 @@
 
 /*! \file */
 
+#include <stdbool.h>
+
 #include <isc/result.h>
 #include <dns/types.h>
 
@@ -24,13 +26,13 @@
 
 ISC_LANG_BEGINDECLS
 
-isc_boolean_t
+bool
 dns__tsig_algvalid(unsigned int alg);
 unsigned int
 dns__tsig_algfromname(const dns_name_t *algorithm);
 const dns_name_t *
 dns__tsig_algnamefromname(const dns_name_t *algorithm);
-isc_boolean_t
+bool
 dns__tsig_algallocated(const dns_name_t *algorithm);
 
 ISC_LANG_ENDDECLS
