@@ -58,8 +58,7 @@ isc_heap_delete_test(void **state) {
 
 	UNUSED(state);
 
-	result = isc_mem_create(0, 0, &mctx);
-	assert_int_equal(result, ISC_R_SUCCESS);
+	isc_mem_create(&mctx);
 
 	result = isc_heap_create(mctx, compare, idx, 0, &heap);
 	assert_int_equal(result, ISC_R_SUCCESS);
